# Generated by roxygen2: do not edit by hand

S3method(plot,Bioenergetic)
S3method(plot,fb4_result)
S3method(print,Bioenergetic)
S3method(print,fb4_result)
S3method(run_fb4,Bioenergetic)
S3method(run_fb4,default)
S3method(set_diet,Bioenergetic)
S3method(set_environment,Bioenergetic)
S3method(set_simulation_settings,Bioenergetic)
S3method(summary,Bioenergetic)
S3method(summary,fb4_result)
export(Bioenergetic)
export(accumulate_validations)
export(analyze_composition_by_size)
export(analyze_composition_changes)
export(analyze_energy_budget)
export(analyze_feeding_performance)
export(analyze_growth_patterns)
export(analyze_growth_temperature_sensitivity)
export(analyze_population_variation)
export(assess_diet_quality)
export(calculate_body_composition)
export(calculate_confidence_intervals)
export(calculate_consumption)
export(calculate_contaminant_accumulation)
export(calculate_egestion)
export(calculate_excretion)
export(calculate_final_weight_fb4)
export(calculate_mortality_reproduction)
export(calculate_np_ratios)
export(calculate_nutrient_balance)
export(calculate_nutrient_efficiencies)
export(calculate_predator_energy_density)
export(calculate_respiration)
export(calculate_stoichiometric_balance)
export(check_numeric_value)
export(clamp)
export(compare_individuals)
export(compare_scenarios)
export(compare_with_redfield)
export(comprehensive_nutritional_analysis)
export(create_empty_composition)
export(create_result_summary)
export(get_consumption_uncertainty)
export(get_efficiency_uncertainty)
export(get_energy_budget_uncertainty)
export(get_individual_results)
export(get_parameter_value)
export(get_population_results)
export(interpolate_time_series)
export(is.Bioenergetic)
export(is.fb4_result)
export(plot_distributions.fb4_result)
export(plot_growth_temperature_sensitivity)
export(plot_sensitivity.fb4_result)
export(plot_uncertainty.fb4_result)
export(predict_consumption_bootstrap)
export(predict_consumption_delta)
export(prepare_simulation_data)
export(process_bioenergetic_data)
export(process_composition_params)
export(process_consumption_params)
export(process_contaminant_params)
export(process_egestion_params)
export(process_excretion_params)
export(process_mortality_params)
export(process_nutrient_params)
export(process_predator_params)
export(process_respiration_params)
export(process_simulation_settings)
export(process_species_parameters)
export(run_fb4)
export(run_fb4_simulation)
export(safe_exp)
export(safe_sqrt)
export(set_diet)
export(set_environment)
export(set_parameter_value)
export(set_simulation_settings)
export(update_body_composition)
export(validate_basic_params)
export(validate_bioenergetic_for_simulation)
export(validate_body_composition)
export(validate_complete_simulation_data)
export(validate_contaminant_params)
export(validate_data_consistency)
export(validate_diet_consistency)
export(validate_equation_params)
export(validate_fb4_inputs)
export(validate_fb4_system)
export(validate_fitting_settings)
export(validate_fraction)
export(validate_individual_data)
export(validate_nutrient_concentrations)
export(validate_positive)
export(validate_predator_energy_params)
export(validate_species_equations)
export(validate_temperature)
export(validate_temporal_data)
export(validate_time_series_data)
export(validation_result)
importFrom(Rcpp,sourceCpp)
importFrom(TMB,MakeADFun)
importFrom(TMB,dynlib)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.off)
importFrom(grDevices,gray.colors)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rug)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,approx)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,dlnorm)
importFrom(stats,lowess)
importFrom(stats,median)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,spline)
importFrom(stats,var)
importFrom(tools,file_ext)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(fb4package, .registration = TRUE)
